#include "kernelmessageswindow.h"
#include "ui_kernelmessageswindow.h"

KernelMessagesWindow::KernelMessagesWindow(QWidget *parent) :
    QMainWindow(parent),
    ui(new Ui::KernelMessagesWindow)
{
    ui->setupUi(this);
    connect(ui->actionExport, SIGNAL(triggered()), this, SLOT(exportlogs()));
#ifdef Q_WS_MAEMO_5
    setAttribute(Qt::WA_Maemo5StackedWindow);
//    ui->textBrowser->setStyleSheet(QString::fromUtf8("background-color: rgb(255, 255, 255);"));
//    ui->textBrowser->setTextColor(QColor("red"));
#endif
    this->showLogs();
    QMainWindow::setCentralWidget(ui->verticalLayoutWidget);
//    QRect screenGeometry = QApplication::desktop()->screenGeometry();
//    ui->textBrowser->setStyleSheet(QString::fromUtf8("background-color: rgb(255, 255, 255);"));
}

KernelMessagesWindow::~KernelMessagesWindow()
{
    delete ui;
    system("rm /home/user/.tempdmesg");
}

void KernelMessagesWindow::showLogs()
{
    system("touch ~/.tempdmesg");
#ifdef Q_WS_MAEMO_5
    system("dmesg | grep PSFreedom* | sed 's/$/\\<br\\>/' > ~/.tempdmesg");
#else
    system("dmesg | sed 's/$/\\<br\\>/' > ~/.tempdmesg");
#endif
    ui->textBrowser->setSource(QUrl("file:///home/user/.tempdmesg"));
}

void KernelMessagesWindow::exportlogs()
{
    system("dmesg | grep PSFreedom* > /home/user/MyDocs/PSFreedom.txt");
#ifdef Q_WS_MAEMO_5
    QMaemo5InformationBox::information(0, tr("Saved to /home/user/MyDocs/PSFreedom.txt"));
#endif
}
